@@ -33,11 +33,11 @@ class Row(FormatRow):
     subgroup_id: int
     is_top_driver: bool
     factor_0_dimension: str
-    factor_0_value: str
+    factor_0_value: any
     factor_1_dimension: str
-    factor_1_value: str
+    factor_1_value: any
     factor_2_dimension: str
-    factor_2_value: str
+    factor_2_value: any
 
     def __str__(self):
         variables = []
@@ -220,7 +220,7 @@ def get_table_general_performance(
     )
 
 
-def to_table(result: LatestAnalysisResultResponse) -> LatestAnalysisResultTable:
+def _to_table(result: LatestAnalysisResultResponse) -> LatestAnalysisResultTable:
     key_driver_analysis_result = result.analysis_result.key_driver_analysis_result
 
     subgroups = key_driver_analysis_result.subgroups
@@ -232,3 +232,14 @@ def to_table(result: LatestAnalysisResultResponse) -> LatestAnalysisResultTable:
         return get_table_general_performance(subgroups)
     else:
         raise ValueError("Invalid analysis_result")
+
+
+def to_table(result: LatestAnalysisResultResponse, force_factor_value_to_str: bool = True) -> LatestAnalysisResultTable:
+    table = _to_table(result)
+    if force_factor_value_to_str:
+        for i, row in enumerate(table.rows):
+            row: Row = row
+            table.rows[i].factor_0_value = str(row.factor_0_value)
+            table.rows[i].factor_1_value = str(row.factor_1_value)
+            table.rows[i].factor_2_value = str(row.factor_2_value)
+    return table
